@@ -16,6 +16,27 @@ is harder to define.
 from conceptnet5.language.english import normalize as normalize_english
 from conceptnet5.uri import normalize_text, concept_uri, split_uri, BAD_NAMES_FOR_THINGS
 
+LCODE_ALIASES = {
+    # Pretend that all Chinese languages and variants are equivalent. This is
+    # linguistically problematic, but it's also very helpful for aligning them
+    # on terms where they actually are the same.
+    #
+    # This would mostly be a problem if ConceptNet was being used to *generate*
+    # Chinese natural language text, and I don't believe it is.
+    'cmn': 'zh',
+    'yue': 'zh',
+    'nan': 'zh',
+    'zh_TW': 'zh',
+    'zh_CN': 'zh',
+
+    # An easier case: consider Bahasa Indonesia and Bahasa Malay to be the
+    # same language, with code 'ms', because they're already 90% the same.
+    # Many sources use 'ms' to represent the entire macrolanguage, with
+    # 'zsm' to refer to Bahasa Malay in particular.
+    'zsm': 'ms',
+    'id': 'ms'
+}
+
 
 def normalized_concept_name(lang, text):
     """
@@ -50,8 +71,10 @@ def normalized_concept_uri(lang, text, *more):
     >>> normalized_concept_uri('en', 'this is a test', 'n', 'example phrase')
     '/c/en/this_be_test/n/example_phrase'
     """
+    if lang in LCODE_ALIASES:
+        lang = LCODE_ALIASES[lang]
     norm_text = normalized_concept_name(lang, text)
-    more_text = [normalize_text(item) for item in more]
+    more_text = [normalize_text(item) for item in more if item is not None]
     return concept_uri(lang, norm_text, *more_text)
 
 
